@@ -1,7 +1,5 @@
 package Dist::Zilla::PluginBundle::LEONT;
-{
-  $Dist::Zilla::PluginBundle::LEONT::VERSION = '0.012';
-}
+$Dist::Zilla::PluginBundle::LEONT::VERSION = '0.013';
 use strict;
 use warnings;
 
@@ -35,7 +33,6 @@ ManifestSkip
 MetaYAML
 License
 Readme
-ExtraTests
 /,
 [ ExecDir => { dir => 'script' } ],
 qw/
@@ -51,13 +48,14 @@ MetaProvides::Package
 
 NextRelease
 CheckChangesHasContent
+Git::Contributors
 /);
 
 # AutoPrereqs should be before installtool (for BuildSelf), InstallGuide should be after it.
 # UploadToCPAN should be after @Git
 
-my @plugins_late = qw/
-TestRelease
+my @plugins_late = (qw/
+RunExtraTests
 ConfirmRelease
 UploadToCPAN
 
@@ -65,18 +63,20 @@ PodWeaver
 PkgVersion
 
 PodSyntaxTests
-PodCoverageTests
-Test::Compile
-/;
+PodCoverageTests/,
+[ 'Test::Compile', { xt_mode => -d 't' } ],
+);
 
 my @bundles = qw/Git/;
 
 my %tools = (
-	eumm => [ 'MakeMaker' ],
-	mb   => [ 'ModuleBuild' ],
-	mbc  => [ qw/ModuleBuild::Custom Meta::Dynamic::Config/ ],
-	mbt  => [ 'ModuleBuildTiny' ],
-	self => [ 'BuildSelf' ],
+	eumm          => [ 'MakeMaker' ],
+	mb            => [ 'ModuleBuild' ],
+	mbc           => [ qw/ModuleBuild::Custom Meta::Dynamic::Config/ ],
+	mbt           => [ 'ModuleBuildTiny' ],
+	self          => [ 'BuildSelf' ],
+	'mbt+mb'      => [ 'ModuleBuildTiny::Fallback' ],
+	'mbt+mb+eumm' => [ 'ModuleBuildTiny::Fallback', 'MakeMaker::Fallback' ],
 	none => [],
 );
 
@@ -94,6 +94,10 @@ sub configure {
 	return;
 }
 
+__PACKAGE__->meta->make_immutable;
+
+no Moose;
+
 1;
 
 # ABSTRACT: LEONT's dzil bundle
@@ -110,35 +114,33 @@ Dist::Zilla::PluginBundle::LEONT - LEONT's dzil bundle
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 DESCRIPTION
 
 This is currently identical to the following setup:
 
-    ; @Basic except for MakeMaker and ExecDir
+    ; @Basic except for MakeMaker, ExecDir, TestRelease and ExtraTests
     [GatherDir]
     [PruneCruft]
     [ManifestSkip]
     [MetaYAML]
     [License]
     [Readme]
-    [ExtraTests]
     [ShareDir]
     [Manifest]
-    [TestRelease]
     [ConfirmRelease]
     [UploadToCPAN]
 
     [ExecDir]
     dir = script
 
+    [RunExtraTests]
     [AutoPrereqs]
     [MetaJSON]
-    [MetaResources]
     [Repository]
     [Bugtracker]
-    [MinimumPerl]
+    [MinimumPerl] ; [MinimumPerlFast] if fast=true
     [Git::NextVersion]
     
     [NextRelease]
@@ -154,10 +156,16 @@ This is currently identical to the following setup:
     [PodSyntaxTests]
     [PodCoverageTests]
     [Test::Compile]
+    xt_mode = 1 ; unless no other tests
     
     [@Git]
+    [Git::Contributors]
 
-The install_tool parameter can currently have 5 different values:
+=head2 Parameters
+
+=head2 install_tool
+
+This parameter can currently have 5 different values:
 
 =over 4
 
@@ -181,9 +189,27 @@ Use Module::Build::Tiny
 
 Use the installing module to bootstrap itself
 
+=item * mbt+mb
+
+Use Module::Build::Tiny with a Module::Build fallback
+
+=item * mbt+mb+eumm
+
+Use Module::Build::Tiny with a Module::Build and a ExtUtils::MakeMaker fallback
+
+=item * none
+
+Don't let this bundle add an install tool, this will need to be set manually. This also disables C<[InstallGuide]>.
+
 =back
 
-=for Pod::Coverage configure
+=head3 fast
+
+This picks some alternative modules. Currently it replaces MinimumPerl by MinimumPerlFast.
+
+=head3 tracker
+
+This picks which bugtracker to use, options are C<github> and C<rt>.
 
 =head1 AUTHOR
 
